clear
set more off
set matsize 1000

*Use appropriate path file
use "\lpf_base_web.dta", clear

log using "replication_lpf_cook_t2-t8.log", replace


local ag "ln_ma pc_lnar_lnas"
local da "plow_positive_crops plow_negative_crops past_suit avg_tsetse"
local tech "ln_frontdist1500 roman"
local geog "ln_abslat distcr1000"
local rfe "scan europe africa"
local bc "`ag' `da' `tech' `geog'"
local bs "ln_ma!=. & pc_lnar_lnas!=. & past_suit!=. & ln_frontdist1500!=. & roman!=. & ln_abslat!=. & distcr1000!=."


********************************
*** T2. Baseline Estimation  ***
********************************

*Bivariate
reg ln_pd1500 lpf_pi if `bs' , rob

*Continent Controls
reg ln_pd1500 lpf_pi `rfe' if `bs', rob

*Agriculture
reg ln_pd1500 lpf_pi `ag' `rfe' if `bs', rob

*Domesticate Animals
reg ln_pd1500 lpf_pi `da' `rfe' if `bs', rob

*Technology
reg ln_pd1500 lpf_pi `tech' `rfe' if `bs', rob

*Geogaphry
reg ln_pd1500 lpf_pi `geog' `rfe' if `bs', rob

*All--Extended
reg ln_pd1500 lpf_pi `bc' `rfe' if `bs', rob

*All--Conservative
reg ln_pd1500 lpf_pi `bc' `rfe' if `bs' & conservative==1, rob


*************************************
***  T3. % Indigenous Truncation  ***
*************************************
 
* > 50% 
reg ln_pd1500 lpf_pi `bc' `rfe' if pown>.5 & `bs', rob

* > 75% 
reg ln_pd1500 lpf_pi `bc' `rfe' if pown>.75 & `bs', rob

* > 85% 
reg ln_pd1500 lpf_pi `bc' `rfe' if pown>.85 & `bs', rob

* > 95% 
reg ln_pd1500 lpf_pi `bc' `rfe' if pown>.95 & `bs', rob



****************************************
***  T4. Within Continent Truncation ***
****************************************

*Europe
reg ln_pd1500 lpf_pi `bc' scan if europe==1 & `bs',rob 

*Africa
reg ln_pd1500 lpf_pi `bc' if africa==1 & `bs',rob 

*Asia
reg ln_pd1500 lpf_pi `bc' if asia==1 & `bs',rob 

*No Europe
reg ln_pd1500 lpf_pi `bc' asia if europe==0 & `bs',rob 

*Eurasia
reg ln_pd1500 lpf_pi `bc' scan asia if africa==0 & `bs',rob 



******************************
***  T5. Omitted Variables ***
******************************

local ov "dq25!=. & pdiv!=. & ln_sw_fst!=. & malaria!=. & ln_rugged!=. & tropical!=. & desert!=. & sh_1500!=. & economic_complexity!=. & husbandry!=."
local kg "tropical desert zsubtrop zboreal zdrytemp zwettemp zpolar"

*Sample Adjustment
reg ln_pd1500 lpf_pi `bc' `rfe' if `bs' & `ov', rob

*Celiac's Disease
reg ln_pd1500 lpf_pi dq25 `bc' `rfe' if `bs' & `ov', rob

*Genetic Capital
reg ln_pd1500 lpf_pi pdiv ln_sw_fst `bc' `rfe' if `bs' & `ov', rob

*Geography/Climate
reg ln_pd1500 lpf_pi malaria elevavg `kg' temp t2 precip p2 ln_rugged `bc' `rfe' if `bs' & `ov', rob

*Historic Culture
reg ln_pd1500 lpf_pi sh_1500 economic_complexity husbandry `bc' `rfe' if `bs' & `ov', rob

*Biogeography
reg ln_pd1500 lpf_pi animals plants `bc' `rfe' if `bs' & `ov', rob

*All--Excluding Biogeographic
reg ln_pd1500 lpf_pi dq25 pdiv ln_sw_fst  elevavg `kg' temp t2 precip p2 ln_rugged  malaria sh_1500 economic_complexity husbandry `bc' `rfe', rob

*All
reg ln_pd1500 lpf_pi dq25 pdiv ln_sw_fst elevavg `kg' temp t2 precip p2 ln_rugged malaria sh_1500 economic_complexity husbandry animals plants `bc' `rfe', rob


*************************************************
***  T6. Historic Effects of Milk Consumption ***
*************************************************

local ay "ln_pd1500!=. & ln_pd1000!=. & ln_pd1!=."

**Effect on Earlier Periods**
*1
reg ln_pd1 lpf_pi `bc' `rfe' if `bs' & `ay', rob

*1000
reg ln_pd1000 lpf_pi `bc' `rfe' if `bs' & `ay', rob 

*1500
reg ln_pd1500 lpf_pi `bc' `rfe' if `bs' & `ay', rob 

**Controlling for Earlier Periods**
*1000
reg ln_pd1500 lpf_pi ln_pd1000 `bc' `rfe' if `bs' & `ay', rob 

*1
reg ln_pd1500 lpf_pi ln_pd1 `bc' `rfe' if `bs' & `ay', rob 


*********************************************************
***  T7. Lactase Persistence and Pre-Colonial Income  ***
*********************************************************

*Urbanization in 1500 (Share in > 40K)
reg cps1500 lpf_pi if `bs' & ln_pd1500!=. & cps1000!=., rob

reg cps1500 lpf_pi `bc' `rfe' if `bs' & ln_pd1500!=. & cps1000!=., rob

*Urbanization in 1000 (Share in > 40K)
reg cps1000 lpf_pi if `bs' & ln_pd1500!=., rob

reg cps1000 lpf_pi `bc' `rfe' if `bs' & ln_pd1500!=., rob

*Controlling for Urbanization
reg ln_pd1500 lpf_pi cps1500 `bc' `rfe' if `bs' & cps100!=., rob 

reg ln_pd1500 lpf_pi cps1000 `bc' `rfe' if `bs' , rob 



****************************************************
*** T8. Contemporary Effects of Milk Consumption ***
****************************************************
local ay2 " ln_pd2000!=. & ln_ypc00!=. & ln_frac!=."


*2000--PD
reg ln_pd2000 lpf_pres mw_lpd1500 mw_ln_ma ln_frac pc_lnar_lnas `da' ln_abslat distcr1000 africa europe scan if `bs' & `ay2', rob

*2000--YPC
reg ln_ypc00 lpf_pres mw_lpd1500 mw_ln_ma ln_frac pc_lnar_lnas `da' ln_abslat distcr1000 africa europe scan if `bs' & `ay2', rob





log close
